@@ -18,6 +18,11 @@ from llvmlite.binding import ffi
 from . import TestCase
 
 
+# arvm7l needs extra ABI symbols to link successfully
+if platform.machine() == 'armv7l':
+    llvm.load_library_permanently('libgcc_s.so.1')
+
+
 def no_de_locale():
     cur = locale.setlocale(locale.LC_ALL)
     try:
@@ -225,7 +230,7 @@ class TestMisc(BaseTest):
             self.assertIsInstance(v, bool)
         self.assertIsInstance(features.flatten(), str)
 
-        re_term = r"[+\-][a-zA-Z0-9\._]+"
+        re_term = r"[+\-][a-zA-Z0-9\._-]+"
         regex = r"^({0}|{0}(,{0})*)?$".format(re_term)
         # quick check for our regex
         self.assertIsNotNone(re.match(regex, ""))
@@ -636,6 +641,10 @@ class JITWithTMTestMixin(JITTestMixin):
         ee = self.jit(mod, target_machine)
         raw_asm = target_machine.emit_assembly(mod)
         self.assertIn("sum", raw_asm)
+        target_machine.set_asm_verbosity(True)
+        raw_asm_verbose = target_machine.emit_assembly(mod)
+        self.assertIn("sum", raw_asm)
+        self.assertNotEqual(raw_asm, raw_asm_verbose)
 
     def test_emit_object(self):
         """Test TargetMachineRef.emit_object()"""
